<?php

/**
 * Name:   Slashdot Theme
 * Date:   January 3, 2000
 * Comment This theme tries to mimic the color scheme from the
 *         "News for Nerds" web site, www.slashdot.org.
 *
 * @author Luke Ehresman
 * @copyright &copy; 2000-2006 The SquirrelMail Project Team
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * @version $Id: slashdot_theme.php,v 1.12 2006/01/23 18:46:27 tokul Exp $
 * @package squirrelmail
 * @subpackage themes
 */

global $color;
$color[0]   = '#dcdcdc'; // (light gray)     TitleBar
$color[1]   = '#800000'; // (red)
$color[2]   = '#cc0000'; // (light red)      Warning/Error Messages
$color[3]   = '#006668'; // (/. color)       Left Bar Background
$color[4]   = '#ffffff'; // (white)          Normal Background
$color[5]   = '#bababa'; // (darker gray)    Table Headers
$color[6]   = '#000000'; // (black)          Text on left bar
$color[7]   = '#004949'; // (light /. color) Links
$color[8]   = '#000000'; // (black)          Normal text
$color[9]   = '#ababab'; // (mid-gray)       Darker version of #0
$color[10]  = '#666666'; // (dark gray)      Darker version of #9
$color[11]  = '#770000'; // (dark red)       Special Folders color
$color[12]  = '#eaeaea';
$color[15]  = '#ababab'; // (mid-gray)       Unselectable folders

?>